@@ -58,6 +58,9 @@ class Assistant(QWidget):
             napari_viewer.events.active_layer.connect(self._on_active_layer_change)
         self._layers: Dict[Layer, Tuple[QtViewerDockWidget, FunctionGui]] = {}
 
+        # visualize intermediate results human-readable from top-left to bottom-right
+        self._viewer.grid.stride = -1
+
         icon_grid = ButtonGrid(self)
         icon_grid.addItems(CATEGORIES)
         icon_grid.itemClicked.connect(self._on_item_clicked)
@@ -153,8 +156,11 @@ class Assistant(QWidget):
         graph = {}
         name_dict = {}
         for layer, (dw, mgui) in self._layers.items():
-            key = layer.metadata.get(OP_ID)
-            if not key:
+            key = None
+            if isinstance(layer.metadata, dict):
+                key = layer.metadata.get(OP_ID)
+
+            if key is None:
                 key = "some_random_key"
 
             args = []
@@ -163,10 +169,13 @@ class Assistant(QWidget):
                 if w.name in (VIEWER_PARAM, OP_NAME_PARAM):
                     continue
                 if "napari.layers" in type(w.value).__module__:
-                    op_id = w.value.metadata.get(OP_ID)
+                    op_id = None
+                    if isinstance(w.value.metadata, dict):
+                        op_id = w.value.metadata.get(OP_ID)
                     if op_id is None:
                         op_id = "some_random_key"
-                        graph[self._id_to_name(op_id, name_dict)] = (cle.imread, ["w.value._source"], [])  # TODO
+                        source = str(w.value.source.path).replace("\\", "/") if w.value.source is not None else "file"
+                        graph[self._id_to_name(op_id, name_dict)] = (cle.imread, ["'" + source + "'"], [])  # TODO
                     inputs.append(self._id_to_name(op_id, name_dict))
                 else:
                     args.append(w.value)
